/* Default */
/*-----------------------------------------------------------------------------*/
html {overflow-y:scroll;}
h1,h2,h3{margin-top: 0 !important;}

a{text-decoration: none !important;}
a,input,select,textarea,button{outline: none !important;}
a.list-group-item.active{color: #428bca; background-color: #fff; border-color: #dddddd;}
a.list-group-item.active:hover{color: #428bca; background-color: #f5f5f5; border-color: #dddddd;}
a#service-manage-status i{float: right; font-size: 35px; margin-top: 5px;}

table td{vertical-align: middle !important;}
table .progress{margin: 0; width: 50%}

.label{padding: 0.3em 0.6em;}
.wrap{overflow: hidden;}
.center-text{text-align: center;}
.c-default{color: #333 !important;}
.c-remove{color:#d2322d !important;}
.c-ok{color: #47a447 !important;}
.c-skip{color: #ed9c28 !important;}
.c-highlight{color: #3276b1!important;}

div.popover {max-width: 550px !important;}
.popover-content hr{margin: 5px 0;}
#log-filter label{font-weight: normal;}

.glyphicon-refresh {
	animation-name: rotateThis;
	animation-duration: .5s;
	animation-iteration-count: infinite;
	animation-timing-function: linear;
}

@keyframes rotateThis {
	from { transform: scale( 1 ) rotate( 0deg );   }
	to   { transform: scale( 1 ) rotate( 360deg ); }
}

