{% if notifications %}
    <div class="panel panel-default">
      <div class="panel-heading">Notifications  <a href="{% url 'ftpdeploy_notification_add' %}" class="btn btn-default btn-xs pull-right"><i class="fa fa-plus"></i> Add Notification</a></div>

      <table class="table table-hover">
            <thead>
                <tr>
                    <th>Name</th>
                    <th></th>
                </tr>
            </thead>
            <tbody id="notification-list">

            {% for notification in notifications %}
                <tr>
                    <td>{{notification.name}}</td>
                    <td>
                        <div class="btn-group pull-right notification-actions">
                            <a href="{% url 'ftpdeploy_notification_edit' notification.pk %}" type="button" class="btn btn-primary btn-xs">Edit</a>
                            <button type="button" class="btn btn-primary dropdown-toggle btn-xs" data-toggle="dropdown">
                                <span class="caret"></span>
                                <span class="sr-only">Toggle Dropdown</span>
                            </button>
                            <ul class="dropdown-menu" role="menu">
                                <li><a href="{% url 'ftpdeploy_notification_delete' notification.pk %}" id="notification-delete">Delete</a></li>
                            </ul>
                        </div>
                    </td>
                 </tr>
            {% endfor %}
            </tbody>
         </table>

    </div>
   
{% else %}
   <div class="well">
        <h4>You don't have any notifications yet!</h4>
        <p> Create the notifications and assign them to services.</p>
        <a href="{% url 'ftpdeploy_notification_add'%}" type="button" class="btn btn-success"><i class="fa fa-plus"></i> Add Notification</a>
   </div>


{% endif %}
    


                    
                