{% extends 'ftp_deploy/base.html' %}

{% block title %}
    <h2>Services <small>Dashboard</small></h2> 
{% endblock title %}

{% block content %}
    <br>
    <div class="row">
        <div class="col-sm-4">
            {% include "ftp_deploy/menu.html" with filter='services' %}
        </div>
        <div class="col-sm-8">
            {% include "ftp_deploy/service/list.html" %}
        </div>
    </div>

    {% include "ftp_deploy/pagination.html" %}

{% endblock content %}