{% load crispy_forms_tags %}
<div class="modal fade" id="notification-modal" tabindex="-1" role="dialog" aria-labelledby="Notification" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                <h4 class="modal-title" id="myModalLabel">Notification</h4>
            </div>
            <form action="{% url 'ftpdeploy_service_notification' service.pk %}" method="post" id="notification-form">
                <div class="modal-body">
                    {% crispy form %}
                </div>
                <div class="modal-footer">
                        <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                        <button type="submit" class="btn btn-primary">Save Notification</button>
                </div>
            </form>
        </div>
    </div>
</div>