{% load staticfiles %}
{% load crispy_forms_tags %}

<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>FTP Deploy - Log In</title>
    <link href="{% static "ftp_deploy/css/bootstrap.min.css"%} " rel="stylesheet" type="text/css">
    <link href="{% static "ftp_deploy/css/login.css"%} " rel="stylesheet" type="text/css">

</head>

<body>
    <div class="container">
        {% block content_login %}
            <form method="post" class="form-signin">
                {% csrf_token %}
                <h2 class="form-signin-heading">FTP Deploy <small>Login</small></h2>
                {% if messages %} {% for message in messages %} <div class="alert alert-danger">{{ message }}</div> {% endfor %} {% endif %}
            	{% crispy form %}
            </form>
        {% endblock content_login %}
    </div> 
  </body>
</html>
