{% if logs %}
    {% for log in logs %}
        <tr>
            <td>{{log.service}}</td>
            <td>{{log.service.repo_branch}}</td>
            <td>{{log.created}}</td>
            <td>
                <button class="btn btn-default btn-xs" data-toggle="popover" data-content="{% for commits in log.commits_info %} <small>'{{commits.0}}' ({{commits.1}})</small> <br> <small>{{commits.2}}</small> <hr> {% endfor %}">{{log.commits_info|length}}</button>
            </td>
            <td>{{log.user}} </td>
            <td>
                {% if log.skip %}
                    <i class="fa fa-check c-ok c-skip"></i>
                {% elif log.status %}
                    <i class="fa fa-check c-ok"></i>
                {% else %}
                    <i class="fa fa-times c-remove" data-toggle="tooltip" data-placement="left" title="{{log.status_message}}"></i>
                {% endif %}
            </td>
        </tr>
    {% endfor %}
{% else %}
    <tr>
        <td colspan="6">No Results</td>
    </tr>
{% endif %}
