{% load active_tag %}
<div class="panel panel-default">
    <div class="panel-heading">Menu</div>
    {% if filter == 'services' %}
        <div class="panel-body">
            <form action="{% url 'ftpdeploy_dashboard' %}" method="post" id="service-filter" class="form-horizontal"> 
                {% csrf_token %}
                <legend for="#">Filter</legend>
                <select name="services" class="form-control" placeholder="Select Service">
                    <option></option>
                    {% for service in services %}
                        <option value="{{service.pk}}">{{service.repo_name}}</option>
                    {% endfor %}
                </select>
            </form>
        </div>
    {% endif %}
    <div class="list-group">
        <a href="{% url 'ftpdeploy_dashboard' %}" class="list-group-item {% active 'dashboard' %} "><i class="fa fa-sitemap"></i> Services</a>
        <a href="{% url 'ftpdeploy_notification' %}" class="list-group-item {% active 'notification' %}"><i class="fa fa-envelope-o"></i> Notifications</a>
        {# <a href="#" class="list-group-item {% active 'statistic' %}"><i class="fa fa-bar-chart-o"></i> View Statistics</a> #}
    </div>
</div>