{% load staticfiles %}
{% load active_tag %}

<!DOCTYPE html>
<html>
  <head>
    <meta charset="UTF-8">
    <title>FTP Deploy</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <script src="//ajax.googleapis.com/ajax/libs/jquery/1.10.2/jquery.min.js"></script>
    <link href="{% static "ftp_deploy/css/bootstrap.min.css"%} " rel="stylesheet" type="text/css">
    <link href="{% static "ftp_deploy/css/select2.css"%} " rel="stylesheet" type="text/css">
    <link href="{% static "ftp_deploy/css/select2-bootstrap.css"%} " rel="stylesheet" type="text/css">
    <link href="{% static "ftp_deploy/css/font-awesome.min.css"%} " rel="stylesheet" type="text/css">
    <link href="{% static "ftp_deploy/css/style.css"%} " rel="stylesheet" type="text/css">
    {% block extrahead %} {% endblock %}
   
    <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
      <script src="../../assets/js/html5shiv.js"></script>
      <script src="../../assets/js/respond.min.js"></script>
    <![endif]-->
  </head>
  <body>

    <div class="navbar navbar-default navbar-static-top" role="navigation">
        <div class="container">
            <div class="navbar-header">
                <a class="navbar-brand" href="{% url 'ftpdeploy_dashboard' %}">FTP Deploy</a>
            </div>
            <div class="">
                <ul class="nav navbar-nav">
                    <li class="{% active 'dashboard' %}"><a href="{% url 'ftpdeploy_dashboard' %}">Services</a></li>
                    <li class="{% active 'notification' %}"><a href="{% url 'ftpdeploy_notification'%}" >Notifications</a></li>
                    {# <li class="#"><a href="{% url 'ftpdeploy_statistic'%}">Statistics</a></li> #}
                    <li class="dropdown">
                        <a href="#" class="dropdown-toggle" data-toggle="dropdown">Add <b class="caret"></b></a>
                        <ul class="dropdown-menu">
                            <li class="{% active 'service/add' %}"><a href="{% url 'ftpdeploy_service_add' %}" >Add Service</a></li>
                            <li class="{% active 'notification/add' %}"><a href="{% url 'ftpdeploy_notification_add' %}">Add Notification</a></li>
                      </ul>
                    </li>
                </ul>
                <ul class="nav navbar-nav navbar-right">
                    <li><a href="{% url 'ftpdeploy_log'%}">Log</a></li>
                    <li><a href="{% url 'ftpdeploy_logout' %}"> <i class="fa fa-power-off"></i></a></li>
                 </ul>
            </div>
        </div>
    </div>


    <div class="container">
        
    	<header class="page-header">
            <div class="row">
                <div class="col-sm-12">
                   {% block title %} {% endblock %}
                </div>
            </div>
    		
    	</header>

        <div id="message">
            <div class="row">
                
                <div class="col-sm-12">
                    {% if messages %}
                        {% for message in messages %}
                        <div class="alert alert-{{message.tags}} fade in"> <button data-dismiss="alert" class="close" type="button">×</button> 
                            {{message}}
                        </div> 
                        {% endfor %}
                    {% endif %}
                </div>
            </div>
           
        </div>
        <div id="page">
            {% block content %} {% endblock %}   
        </div>

        <footer>
            
        </footer>
    	
    </div>

    
    <script type="text/javascript"> $.ajaxSetup({data: {csrfmiddlewaretoken:'{{ csrf_token }}'},}); </script>
    <script type="text/javascript" src="{% static "ftp_deploy/js/bootstrap.min.js"%} "></script>
    <script type="text/javascript" src="{% static "ftp_deploy/js/select2.min.js"%} "></script>
    <script type="text/javascript" src="{% static "ftp_deploy/js/script.js"%} "></script>
    {% block extrascript %} {% endblock %}
  </body>
</html>