<html>
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>FTP Deploy</title>
</head>
<body style="font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif; font-size: 14px; line-height: 1.428571429; color: #333333; background-color: #ffffff;">
    <table cellspacing="0" cellpadding="0" border="0" width="500px" style="margin:0 auto; ">
        <tr>
            <td style="border:0;border-bottom:1px solid #eeeeee; padding-bottom: 8px;">
                <span class="label label-success" style="background-color: #d9534f; display: inline; padding: .2em .6em .3em; font-size: 75%; font-weight: bold; line-height: 1; color: #ffffff; text-align: center; white-space: nowrap; vertical-align: baseline; border-radius: .25em;">Fail</span>
            </td> 

            <td align="right" style="border:0;border-bottom:1px solid #eeeeee; padding-bottom: 8px;">
                <a href="https://bitbucket.org/" style="color: #ffffff; background-color: #428bca; border-color: #357ebd; display: inline-block; text-align: center; vertical-align: middle; cursor: pointer; border: 1px solid transparent; white-space: nowrap; padding: 1px 5px; font-size: 12px; line-height: 1.5; border-radius: 3px; text-decoration: none;" >Bitbucket</a> 

                <a href="{{host}}{% url 'ftpdeploy_dashboard' %}" style="color: #ffffff; background-color: #428bca; border-color: #357ebd; display: inline-block; text-align: center; vertical-align: middle; cursor: pointer; border: 1px solid transparent; white-space: nowrap; padding: 1px 5px; font-size: 12px; line-height: 1.5; border-radius: 3px; text-decoration: none;" >FTP Deploy</a> 
            </td>    
        </tr>
        <tr >
            <td colspan="2">
                <h1 style="font-size: 22px; font-weight: bold; line-height: 1.1; border:0;border-bottom:1px solid #eeeeee; padding-bottom: 8px; margin:8px 0">{{service.repo_name}}</h1> 
                <small style="font-size: 12px;">Deploy User: <b>{{service.latest_log_user}}</b></small><br>
                <small style="font-size: 12px;">Deploy Date: <b>{{service.latest_log_date}}</b></small><br>
            </td>
        </tr>
        <tr>
            <td colspan="2" style="padding-top:20px">
                <div class="alert alert-danger" style="background-color: #f2dede; border-color: #ebccd1; color: #b94a48;  padding: 15px; margin-bottom: 20px; border: 1px solid transparent; border-radius: 4px;">{{error}} 
                <br><br>
                <a href="{{host}}{% url 'ftpdeploy_service_manage' service.pk %}" style="color: #ffffff; background-color: #d9534f; border-color: #d43f3a; display: inline-block; text-align: center; vertical-align: middle; cursor: pointer; border: 1px solid transparent; white-space: nowrap; padding: 1px 5px; font-size: 12px; line-height: 1.5; border-radius: 3px; text-decoration: none;" >Manage Service</a> </div>
            </td>
        </tr>
     
       
    </table>
   
</body>
</html>