{% load crispy_forms_filters %}
{% load l10n %}

<tr>
    {% for choice in field.field.choices %}
    <td><input type="checkbox"{% if choice.0 in field.value or choice.0|stringformat:"s" in field.value or choice.0|stringformat:"s" == field.value|stringformat:"s" %} checked="checked"{% endif %} name="{{ field.html_name }}" id="id_{{ field.html_name }}_{{ forloop.counter }}" value="{{ choice.0|unlocalize }}" {{ field.field.widget.attrs|flatatt }}></td>
    {% endfor %}
    <td><small>{{ field.label|safe|upper }}</small></td>
    <td></td>
</tr>