{% extends 'ftp_deploy/base.html' %}

{% block content %}
       
    <div class="row">
        <div class="col-sm-12">
           <form action="{% url 'ftpdeploy_notification_delete' notification.pk %}" method="post">{% csrf_token %}
               <a href="{% url 'ftpdeploy_notification' %}" class="btn btn-default btn-xs">Cancel</a>
               <button type="submit" class="btn btn-danger btn-xs">Delete</button>
           </form>
        </div>
    </div>

{% endblock content %}