.form-control .select2-choice {
    border: 0;
    border-radius: 2px;
}

.form-control .select2-choice .select2-arrow {
    border-radius: 0 2px 2px 0;   
}

.form-control.select2-container {
    height: auto !important;
    padding: 0px;
}

.form-control.select2-container.select2-dropdown-open {
    border-color: #5897FB;
    border-radius: 3px 3px 0 0;
}

.form-control .select2-container.select2-dropdown-open .select2-choices {
    border-radius: 3px 3px 0 0;
}

.form-control.select2-container .select2-choices {
    border: 0 !important;
    border-radius: 3px;
}

.control-group.warning .select2-container .select2-choice,
.control-group.warning .select2-container .select2-choices,
.control-group.warning .select2-container-active .select2-choice,
.control-group.warning .select2-container-active .select2-choices,
.control-group.warning .select2-dropdown-open.select2-drop-above .select2-choice,
.control-group.warning .select2-dropdown-open.select2-drop-above .select2-choices,
.control-group.warning .select2-container-multi.select2-container-active .select2-choices {
    border: 1px solid #C09853 !important;
}

.control-group.warning .select2-container .select2-choice div {
    border-left: 1px solid #C09853 !important;
    background: #FCF8E3 !important;
}

.control-group.error .select2-container .select2-choice,
.control-group.error .select2-container .select2-choices,
.control-group.error .select2-container-active .select2-choice,
.control-group.error .select2-container-active .select2-choices,
.control-group.error .select2-dropdown-open.select2-drop-above .select2-choice,
.control-group.error .select2-dropdown-open.select2-drop-above .select2-choices,
.control-group.error .select2-container-multi.select2-container-active .select2-choices {
    border: 1px solid #B94A48 !important;
}

.control-group.error .select2-container .select2-choice div {
    border-left: 1px solid #B94A48 !important;
    background: #F2DEDE !important;
}

.control-group.info .select2-container .select2-choice,
.control-group.info .select2-container .select2-choices,
.control-group.info .select2-container-active .select2-choice,
.control-group.info .select2-container-active .select2-choices,
.control-group.info .select2-dropdown-open.select2-drop-above .select2-choice,
.control-group.info .select2-dropdown-open.select2-drop-above .select2-choices,
.control-group.info .select2-container-multi.select2-container-active .select2-choices {
    border: 1px solid #3A87AD !important;
}

.control-group.info .select2-container .select2-choice div {
    border-left: 1px solid #3A87AD !important;
    background: #D9EDF7 !important;
}

.control-group.success .select2-container .select2-choice,
.control-group.success .select2-container .select2-choices,
.control-group.success .select2-container-active .select2-choice,
.control-group.success .select2-container-active .select2-choices,
.control-group.success .select2-dropdown-open.select2-drop-above .select2-choice,
.control-group.success .select2-dropdown-open.select2-drop-above .select2-choices,
.control-group.success .select2-container-multi.select2-container-active .select2-choices {
    border: 1px solid #468847 !important;
}

.control-group.success .select2-container .select2-choice div {
    border-left: 1px solid #468847 !important;
    background: #DFF0D8 !important;
}
